==> haskell-deferred-folds-0.9.10.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10.1
id: deferred-folds-0.9.10.1-JVyWO0vzmkrDuKCzjXw5OX
key: deferred-folds-0.9.10.1-JVyWO0vzmkrDuKCzjXw5OX
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: 93509fdb42c7aa49cbdb967556af12bd
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/deferred-folds-0.9.10.1
hs-libraries: HSdeferred-folds-0.9.10.1-JVyWO0vzmkrDuKCzjXw5OX
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-BGCK62jFLzTLxEecc2NA9d
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deferred-folds-0.9.10.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-deferred-folds.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deferred-folds
version: 0.9.10.1
id: deferred-folds-0.9.10.1-RSxQa5xcZeC867VbQa9BC
key: deferred-folds-0.9.10.1-RSxQa5xcZeC867VbQa9BC
license: MIT
copyright: (c) 2018, Metrix.AI
maintainer: Metrix.AI Tech Team <tech@metrix.ai>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
stability: Experimental
homepage: https://github.com/metrix-ai/deferred-folds
synopsis: Abstractions over deferred folds
description:
    This library is in an experimental state.
    Users should be prepared for frequent updates.
category: Folding
abi: c59d2e2048558d37b46fef03514ef2a1
exposed: True
exposed-modules:
    DeferredFolds.Unfoldl DeferredFolds.UnfoldlM DeferredFolds.Unfoldr
hidden-modules: DeferredFolds.Types DeferredFolds.UnfoldrM
                DeferredFolds.Defs.Unfoldl DeferredFolds.Defs.UnfoldlM
                DeferredFolds.Defs.Unfoldr DeferredFolds.Defs.UnfoldrM
                DeferredFolds.Prelude
import-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/deferred-folds-0.9.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/deferred-folds-0.9.10.1
hs-libraries: HSdeferred-folds-0.9.10.1-RSxQa5xcZeC867VbQa9BC
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    foldl-1.4.5-EpRZieTwYc03dnMGE5UGsG
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b transformers-0.5.6.2
    unordered-containers-0.2.10.0-1qvqZt81kSY49gkPLj6it0
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-deferred-folds/html/deferred-folds.haddock
haddock-html: /usr/share/doc/haskell-deferred-folds/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
